@@ -1,4 +1,4 @@
-// Copyright 2016-2020, Pulumi Corporation.
+// Copyright 2016-2021, Pulumi Corporation.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -52,10 +52,11 @@ func (ss stringSet) has(s string) bool {
 }
 
 type typeDetails struct {
-	outputType bool
-	inputType  bool
-	stateType  bool
-	plainType  bool
+	outputType                        bool
+	inputType                         bool
+	stateType                         bool
+	plainType                         bool
+	usedInFunctionOutputVersionInputs bool
 }
 
 // Title converts the input string to a title case
@@ -229,6 +230,8 @@ func (mod *modContext) typeName(t *schema.ObjectType, state, input, args bool) s
 	}
 
 	switch {
+	case input && args && mod.details(t).usedInFunctionOutputVersionInputs:
+		return name + "InputArgs"
 	case input:
 		return name + "Args"
 	case mod.details(t).plainType:
@@ -493,12 +496,8 @@ type plainType struct {
 	internal              bool
 }
 
-func (pt *plainType) genInputProperty(w io.Writer, prop *schema.Property, indent string) {
+func (pt *plainType) genInputPropertyAttribute(w io.Writer, indent string, prop *schema.Property) {
 	wireName := prop.Name
-	propertyName := pt.mod.propertyName(prop)
-	propertyType := pt.mod.typeString(prop.Type, pt.propertyTypeQualifier, true, pt.state, false)
-
-	// First generate the input attribute.
 	attributeArgs := ""
 	if prop.IsRequired() {
 		attributeArgs = ", required: true"
@@ -515,6 +514,12 @@ func (pt *plainType) genInputProperty(w io.Writer, prop *schema.Property, indent
 			attributeArgs += ", json: true"
 		}
 	}
+	fmt.Fprintf(w, "%s[Input(\"%s\"%s)]\n", indent, wireName, attributeArgs)
+}
+
+func (pt *plainType) genInputProperty(w io.Writer, prop *schema.Property, indent string, generateInputAttribute bool) {
+	propertyName := pt.mod.propertyName(prop)
+	propertyType := pt.mod.typeString(prop.Type, pt.propertyTypeQualifier, true, pt.state, false)
 
 	indent = strings.Repeat(indent, 2)
 
@@ -536,7 +541,10 @@ func (pt *plainType) genInputProperty(w io.Writer, prop *schema.Property, indent
 		requireInitializers := !pt.args || !isInputType(prop.Type)
 		backingFieldType := pt.mod.typeString(codegen.RequiredType(prop), pt.propertyTypeQualifier, true, pt.state, requireInitializers)
 
-		fmt.Fprintf(w, "%s[Input(\"%s\"%s)]\n", indent, wireName, attributeArgs)
+		if generateInputAttribute {
+			pt.genInputPropertyAttribute(w, indent, prop)
+		}
+
 		fmt.Fprintf(w, "%sprivate %s? %s;\n", indent, backingFieldType, backingFieldName)
 
 		if prop.Comment != "" {
@@ -587,7 +595,11 @@ func (pt *plainType) genInputProperty(w io.Writer, prop *schema.Property, indent
 		}
 
 		printComment(w, prop.Comment, indent)
-		fmt.Fprintf(w, "%s[Input(\"%s\"%s)]\n", indent, wireName, attributeArgs)
+
+		if generateInputAttribute {
+			pt.genInputPropertyAttribute(w, indent, prop)
+		}
+
 		fmt.Fprintf(w, "%spublic %s %s { get; set; }%s\n", indent, propertyType, propertyName, initializer)
 	}
 }
@@ -596,6 +608,10 @@ func (pt *plainType) genInputProperty(w io.Writer, prop *schema.Property, indent
 var generatedTypes = codegen.Set{}
 
 func (pt *plainType) genInputType(w io.Writer, level int) error {
+	return pt.genInputTypeWithFlags(w, level, true /* generateInputAttributes */)
+}
+
+func (pt *plainType) genInputTypeWithFlags(w io.Writer, level int, generateInputAttributes bool) error {
 	// The way the legacy codegen for kubernetes is structured, inputs for a resource args type and resource args
 	// subtype could become a single class because of the name + namespace clash. We use a set of generated types
 	// to prevent generating classes with equal full names in multiple files. The check should be removed if we
@@ -619,12 +635,18 @@ func (pt *plainType) genInputType(w io.Writer, level int) error {
 
 	// Open the class.
 	printCommentWithOptions(w, pt.comment, indent, !pt.unescapeComment)
-	fmt.Fprintf(w, "%spublic %sclass %s : Pulumi.%s\n", indent, sealed, pt.name, pt.baseClass)
+
+	var suffix string
+	if pt.baseClass != "" {
+		suffix = fmt.Sprintf(" : Pulumi.%s", pt.baseClass)
+	}
+
+	fmt.Fprintf(w, "%spublic %sclass %s%s\n", indent, sealed, pt.name, suffix)
 	fmt.Fprintf(w, "%s{\n", indent)
 
 	// Declare each input property.
 	for _, p := range pt.properties {
-		pt.genInputProperty(w, p, indent)
+		pt.genInputProperty(w, p, indent, generateInputAttributes)
 		fmt.Fprintf(w, "\n")
 	}
 
@@ -1253,6 +1275,35 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 	return nil
 }
 
+func (mod *modContext) genFunctionFileCode(f *schema.Function) (string, error) {
+	imports := map[string]codegen.StringSet{}
+	mod.getImports(f, imports)
+	buffer := &bytes.Buffer{}
+	importStrings := pulumiImports
+	for _, i := range imports {
+		importStrings = append(importStrings, i.SortedValues()...)
+	}
+	if f.NeedsOutputVersion() {
+		importStrings = append(importStrings, "Pulumi.Utilities")
+	}
+	mod.genHeader(buffer, importStrings)
+	if err := mod.genFunction(buffer, f); err != nil {
+		return "", err
+	}
+	return buffer.String(), nil
+}
+
+func allOptionalInputs(fun *schema.Function) bool {
+	if fun.Inputs != nil {
+		for _, prop := range fun.Inputs.Properties {
+			if prop.IsRequired() {
+				return false
+			}
+		}
+	}
+	return true
+}
+
 func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) error {
 	className := tokenToFunctionName(fun.Token)
 
@@ -1267,13 +1318,8 @@ func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) error {
 	var argsParamDef string
 	argsParamRef := "InvokeArgs.Empty"
 	if fun.Inputs != nil {
-		allOptionalInputs := true
-		for _, prop := range fun.Inputs.Properties {
-			allOptionalInputs = allOptionalInputs && !prop.IsRequired()
-		}
-
 		var argsDefault, sigil string
-		if allOptionalInputs {
+		if allOptionalInputs(fun) {
 			// If the number of required input properties was zero, we can make the args object optional.
 			argsDefault, sigil = " = null", "?"
 		}
@@ -1298,6 +1344,12 @@ func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) error {
 	fmt.Fprintf(w, "            => Pulumi.Deployment.Instance.InvokeAsync%s(\"%s\", %s, options.WithVersion());\n",
 		typeParameter, fun.Token, argsParamRef)
 
+	// Emit the Output method if needed.
+	err := mod.genFunctionOutputVersion(w, fun)
+	if err != nil {
+		return err
+	}
+
 	// Close the class.
 	fmt.Fprintf(w, "    }\n")
 
@@ -1316,6 +1368,12 @@ func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) error {
 			return err
 		}
 	}
+
+	err = mod.genFunctionOutputVersionTypes(w, fun)
+	if err != nil {
+		return err
+	}
+
 	if fun.Outputs != nil {
 		fmt.Fprintf(w, "\n")
 
@@ -1333,6 +1391,61 @@ func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) error {
 	return nil
 }
 
+func functionOutputVersionArgsTypeName(fun *schema.Function) string {
+	className := tokenToFunctionName(fun.Token)
+	return fmt.Sprintf("%sInvokeArgs", className)
+}
+
+// Generates `${fn}Output(..)` version lifted to work on
+// `Input`-wrapped arguments and producing an `Output`-wrapped result.
+func (mod *modContext) genFunctionOutputVersion(w io.Writer, fun *schema.Function) error {
+	if !fun.NeedsOutputVersion() {
+		return nil
+	}
+	className := tokenToFunctionName(fun.Token)
+
+	var argsDefault, sigil string
+	if allOptionalInputs(fun) {
+		// If the number of required input properties was zero, we can make the args object optional.
+		argsDefault, sigil = " = null", "?"
+	}
+
+	argsTypeName := functionOutputVersionArgsTypeName(fun)
+	outputArgsParamDef := fmt.Sprintf("%s%s args%s, ", argsTypeName, sigil, argsDefault)
+	outputArgsParamRef := fmt.Sprintf("args ?? new %s()", argsTypeName)
+
+	fmt.Fprintf(w, "\n")
+
+	// Emit the doc comment, if any.
+	printComment(w, fun.Comment, "        ")
+	fmt.Fprintf(w, "        public static Output<%sResult> Invoke(%sInvokeOptions? options = null)\n",
+		className, outputArgsParamDef)
+	fmt.Fprintf(w, "            => Pulumi.Deployment.Instance.Invoke<%sResult>(\"%s\", %s, options.WithVersion());\n",
+		className, fun.Token, outputArgsParamRef)
+	return nil
+}
+
+// Generate helper type definitions referred to in `genFunctionOutputVersion`.
+func (mod *modContext) genFunctionOutputVersionTypes(w io.Writer, fun *schema.Function) error {
+	if !fun.NeedsOutputVersion() || fun.Inputs == nil {
+		return nil
+	}
+
+	applyArgs := &plainType{
+		mod:                   mod,
+		name:                  functionOutputVersionArgsTypeName(fun),
+		propertyTypeQualifier: "Inputs",
+		baseClass:             "InvokeArgs",
+		properties:            fun.Inputs.InputShape.Properties,
+		args:                  true,
+	}
+
+	if err := applyArgs.genInputTypeWithFlags(w, 1, true /* generateInputAttributes */); err != nil {
+		return err
+	}
+	return nil
+}
+
 func (mod *modContext) genEnums(w io.Writer, enums []*schema.EnumType) error {
 	// Open the namespace.
 	fmt.Fprintf(w, "namespace %s\n", mod.namespaceName)
@@ -1904,21 +2017,11 @@ func (mod *modContext) gen(fs fs) error {
 
 	// Functions
 	for _, f := range mod.functions {
-		imports := map[string]codegen.StringSet{}
-		mod.getImports(f, imports)
-
-		buffer := &bytes.Buffer{}
-		importStrings := pulumiImports
-		for _, i := range imports {
-			importStrings = append(importStrings, i.SortedValues()...)
-		}
-		mod.genHeader(buffer, importStrings)
-
-		if err := mod.genFunction(buffer, f); err != nil {
+		code, err := mod.genFunctionFileCode(f)
+		if err != nil {
 			return err
 		}
-
-		addFile(tokenToName(f.Token)+".cs", buffer.String())
+		addFile(tokenToName(f.Token)+".cs", code)
 	}
 
 	// Nested types
@@ -1952,7 +2055,6 @@ func (mod *modContext) gen(fs fs) error {
 				return err
 			}
 			fmt.Fprintf(buffer, "}\n")
-
 			addFile(path.Join("Inputs", tokenToName(t.Token)+"GetArgs.cs"), buffer.String())
 		}
 		if mod.details(t).outputType {
@@ -1970,7 +2072,6 @@ func (mod *modContext) gen(fs fs) error {
 			if (mod.isTFCompatMode() || mod.isK8sCompatMode()) && mod.details(t).plainType {
 				suffix = "Result"
 			}
-
 			addFile(path.Join("Outputs", tokenToName(t.Token)+suffix+".cs"), buffer.String())
 		}
 	}
@@ -1990,8 +2091,13 @@ func (mod *modContext) gen(fs fs) error {
 }
 
 // genPackageMetadata generates all the non-code metadata required by a Pulumi package.
-func genPackageMetadata(pkg *schema.Package, assemblyName string, packageReferences map[string]string, files fs) error {
-	projectFile, err := genProjectFile(pkg, assemblyName, packageReferences)
+func genPackageMetadata(pkg *schema.Package,
+	assemblyName string,
+	packageReferences map[string]string,
+	projectReferences []string,
+	files fs) error {
+
+	projectFile, err := genProjectFile(pkg, assemblyName, packageReferences, projectReferences)
 	if err != nil {
 		return err
 	}
@@ -2006,12 +2112,17 @@ func genPackageMetadata(pkg *schema.Package, assemblyName string, packageReferen
 }
 
 // genProjectFile emits a C# project file into the configured output directory.
-func genProjectFile(pkg *schema.Package, assemblyName string, packageReferences map[string]string) ([]byte, error) {
+func genProjectFile(pkg *schema.Package,
+	assemblyName string,
+	packageReferences map[string]string,
+	projectReferences []string) ([]byte, error) {
+
 	w := &bytes.Buffer{}
 	err := csharpProjectFileTemplate.Execute(w, csharpProjectFileTemplateContext{
 		XMLDoc:            fmt.Sprintf(`.\%s.xml`, assemblyName),
 		Package:           pkg,
 		PackageReferences: packageReferences,
+		ProjectReferences: projectReferences,
 	})
 	if err != nil {
 		return nil, err
@@ -2188,6 +2299,13 @@ func generateModuleContextMap(tool string, pkg *schema.Package) (map[string]*mod
 				details.inputType = true
 				details.plainType = true
 			})
+			if f.NeedsOutputVersion() {
+				visitObjectTypes(f.Inputs.InputShape.Properties, func(t *schema.ObjectType) {
+					details := getModFromToken(t.Token, t.Package).details(t)
+					details.inputType = true
+					details.usedInFunctionOutputVersionInputs = true
+				})
+			}
 		}
 		if f.Outputs != nil {
 			visitObjectTypes(f.Outputs.Properties, func(t *schema.ObjectType) {
@@ -2262,7 +2380,12 @@ func GeneratePackage(tool string, pkg *schema.Package, extraFiles map[string][]b
 	}
 
 	// Finally emit the package metadata.
-	if err := genPackageMetadata(pkg, assemblyName, info.PackageReferences, files); err != nil {
+	if err := genPackageMetadata(pkg,
+		assemblyName,
+		info.PackageReferences,
+		info.ProjectReferences,
+		files); err != nil {
+
 		return nil, err
 	}
 	return files, nil
