@@ -101,6 +101,7 @@ type ResourceOptions struct {
 	CustomTimeouts        *resource.CustomTimeouts
 	SupportsPartialValues *bool
 	Remote                bool
+	Providers             map[string]string
 
 	DisableSecrets            bool
 	DisableResourceReferences bool
@@ -187,6 +188,7 @@ func (rm *ResourceMonitor) RegisterResource(t tokens.Type, name string, custom b
 		SupportsPartialValues:      supportsPartialValues,
 		Remote:                     opts.Remote,
 		ReplaceOnChanges:           opts.ReplaceOnChanges,
+		Providers:                  opts.Providers,
 	}
 
 	// submit request
@@ -306,6 +308,56 @@ func (rm *ResourceMonitor) Invoke(tok tokens.ModuleMember, inputs resource.Prope
 	return outs, nil, nil
 }
 
+func (rm *ResourceMonitor) Call(tok tokens.ModuleMember, inputs resource.PropertyMap,
+	provider string, version string) (resource.PropertyMap, map[resource.PropertyKey][]resource.URN,
+	[]*pulumirpc.CheckFailure, error) {
+
+	// marshal inputs
+	ins, err := plugin.MarshalProperties(inputs, plugin.MarshalOptions{
+		KeepUnknowns:  true,
+		KeepResources: true,
+	})
+	if err != nil {
+		return nil, nil, nil, err
+	}
+
+	// submit request
+	resp, err := rm.resmon.Call(context.Background(), &pulumirpc.CallRequest{
+		Tok:      string(tok),
+		Provider: provider,
+		Args:     ins,
+		Version:  version,
+	})
+	if err != nil {
+		return nil, nil, nil, err
+	}
+
+	// handle failures
+	if len(resp.Failures) != 0 {
+		return nil, nil, resp.Failures, nil
+	}
+
+	// unmarshal outputs
+	outs, err := plugin.UnmarshalProperties(resp.Return, plugin.MarshalOptions{
+		KeepUnknowns:  true,
+		KeepResources: true,
+	})
+	if err != nil {
+		return nil, nil, nil, err
+	}
+
+	// unmarshal return deps
+	deps := make(map[resource.PropertyKey][]resource.URN)
+	for _, p := range resp.ReturnDependencies {
+		var urns []resource.URN
+		for _, urn := range p.Urns {
+			urns = append(urns, resource.URN(urn))
+		}
+	}
+
+	return outs, deps, nil, nil
+}
+
 func prepareTestTimeout(timeout float64) string {
 	mins := int(timeout) / 60
 
