@@ -1508,17 +1508,21 @@ namespace Pulumi.Automation.Tests
         [InlineData("2.21.1-alpha.1234", true, false)]
         [InlineData("2.20.0", false, true)]
         [InlineData("2.22.0", false, true)]
+        // Invalid version check
+        [InlineData("invalid", false, true)]
+        [InlineData("invalid", true, false)]
         public void ValidVersionTheory(string currentVersion, bool errorExpected, bool optOut)
         {
             var testMinVersion = SemVersion.Parse("2.21.1");
+
             if (errorExpected)
             {
-                void ValidatePulumiVersion() => LocalWorkspace.ValidatePulumiVersion(testMinVersion, currentVersion, optOut);
+                void ValidatePulumiVersion() => LocalWorkspace.ParseAndValidatePulumiVersion(testMinVersion, currentVersion, optOut);
                 Assert.Throws<InvalidOperationException>(ValidatePulumiVersion);
             }
             else
             {
-                LocalWorkspace.ValidatePulumiVersion(testMinVersion, currentVersion, optOut);
+                LocalWorkspace.ParseAndValidatePulumiVersion(testMinVersion, currentVersion, optOut);
             }
         }
 
