@@ -155,6 +155,28 @@ func (d DiffKind) IsReplace() bool {
 	}
 }
 
+// AsReplace converts a DiffKind into the equivalent replacement if it not already
+// a replacement.
+func (d DiffKind) AsReplace() DiffKind {
+	switch d {
+	case DiffAdd:
+		return DiffAddReplace
+	case DiffAddReplace:
+		return DiffAddReplace
+	case DiffDelete:
+		return DiffDeleteReplace
+	case DiffDeleteReplace:
+		return DiffDeleteReplace
+	case DiffUpdate:
+		return DiffUpdateReplace
+	case DiffUpdateReplace:
+		return DiffUpdateReplace
+	default:
+		contract.Failf("Unknown diff kind %v", int(d))
+		return DiffUpdateReplace
+	}
+}
+
 const (
 	// DiffAdd indicates that the property was added.
 	DiffAdd DiffKind = 0
@@ -176,6 +198,15 @@ type PropertyDiff struct {
 	InputDiff bool     // True if this is a diff between old and new inputs rather than old state and new inputs.
 }
 
+// ToReplace converts the kind of a PropertyDiff into the equivalent replacement if it not already
+// a replacement.
+func (p PropertyDiff) ToReplace() PropertyDiff {
+	return PropertyDiff{
+		InputDiff: p.InputDiff,
+		Kind:      p.Kind.AsReplace(),
+	}
+}
+
 // DiffResult indicates whether an operation should replace or update an existing resource.
 type DiffResult struct {
 	Changes             DiffChanges             // true if this diff represents a changed resource.
