@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-// tslint:disable:max-line-length
+/* eslint-disable max-len */
 
 import * as upath from "upath";
 import { ResourceError } from "../../errors";
@@ -101,7 +101,7 @@ export interface Entry {
     json?: any;
 
     // An RegExp. Will be serialized as 'new RegExp(re.source, re.flags)'
-    regexp?: { source: string, flags: string };
+    regexp?: { source: string; flags: string };
 
     // a closure we are dependent on.
     function?: FunctionInfo;
@@ -181,7 +181,7 @@ interface ContextFrame {
     functionLocation?: FunctionLocation;
     capturedFunctionName?: string;
     capturedVariableName?: string;
-    capturedModule?: { name: string, value: any };
+    capturedModule?: { name: string; value: any };
 }
 
 interface ClosurePropertyDescriptor {
@@ -195,7 +195,7 @@ interface ClosurePropertyDescriptor {
     value?: any;
     writable?: boolean;
     get?: () => any;
-    set?: (v: any)=> void;
+    set?: (v: any) => void;
 }
 
 /*
@@ -213,7 +213,7 @@ class SerializedOutput<T> {
 
     public apply<U>(func: (t: T) => Input<U>): Output<U> {
         throw new Error(
-"'apply' is not allowed from inside a cloud-callback. Use 'get' to retrieve the value of this Output directly.");
+            "'apply' is not allowed from inside a cloud-callback. Use 'get' to retrieve the value of this Output directly.");
     }
 
     public get(): T {
@@ -339,7 +339,7 @@ export async function createClosureInfoAsync(
         // see http://www.ecma-international.org/ecma-262/6.0/#sec-generatorfunction-objects and
         // http://www.ecma-international.org/ecma-262/6.0/figure-2.png
         async function addGeneratorEntriesAsync() {
-            // tslint:disable-next-line:no-empty
+            // eslint-disable-next-line no-empty,no-empty-function,@typescript-eslint/no-empty-function
             const emptyGenerator = function* (): any { };
 
             await addEntriesAsync(
@@ -362,8 +362,8 @@ export async function createClosureInfoAsync(
  * final FunctionInfo.
  */
 async function analyzeFunctionInfoAsync(
-        func: Function, context: Context,
-        serialize: (o: any) => boolean, logInfo?: boolean): Promise<FunctionInfo> {
+    func: Function, context: Context,
+    serialize: (o: any) => boolean, logInfo?: boolean): Promise<FunctionInfo> {
 
     // logInfo = logInfo || func.name === "addHandler";
 
@@ -687,7 +687,7 @@ function throwSerializationError(
     message += getTrimmedFunctionCode(func);
 
     const moduleIndex = context.frames.findIndex(
-            f => f.capturedModule !== undefined);
+        f => f.capturedModule !== undefined);
 
     if (moduleIndex >= 0) {
         const module = context.frames[moduleIndex].capturedModule!;
@@ -782,10 +782,10 @@ async function isDefaultFunctionPrototypeAsync(func: Function, prototypeProp: an
 }
 
 async function createPropertyInfoAsync(
-        descriptor: ClosurePropertyDescriptor,
-        context: Context,
-        serialize: (o: any) => boolean,
-        logInfo: boolean | undefined): Promise<PropertyInfo> {
+    descriptor: ClosurePropertyDescriptor,
+    context: Context,
+    serialize: (o: any) => boolean,
+    logInfo: boolean | undefined): Promise<PropertyInfo> {
 
     const propertyInfo = <PropertyInfo>{ hasValue: descriptor.value !== undefined };
     propertyInfo.configurable = descriptor.configurable;
@@ -793,11 +793,11 @@ async function createPropertyInfoAsync(
     propertyInfo.writable = descriptor.writable;
     if (descriptor.get) {
         propertyInfo.get = await getOrCreateEntryAsync(
-          descriptor.get, undefined, context, serialize, logInfo);
+            descriptor.get, undefined, context, serialize, logInfo);
     }
     if (descriptor.set) {
         propertyInfo.set = await getOrCreateEntryAsync(
-          descriptor.set, undefined, context, serialize, logInfo);
+            descriptor.set, undefined, context, serialize, logInfo);
     }
 
     return propertyInfo;
@@ -818,10 +818,10 @@ function getOrCreateNameEntryAsync(
  * specific properties.  If propNames is not provided, or is empty, serialize out all properties.
  */
 async function getOrCreateEntryAsync(
-        obj: any, capturedObjectProperties: CapturedPropertyChain[] | undefined,
-        context: Context,
-        serialize: (o: any) => boolean,
-        logInfo: boolean | undefined): Promise<Entry> {
+    obj: any, capturedObjectProperties: CapturedPropertyChain[] | undefined,
+    context: Context,
+    serialize: (o: any) => boolean,
+    logInfo: boolean | undefined): Promise<Entry> {
 
     // Check if this is a special number that we cannot json serialize.  Instead, we'll just inject
     // the code necessary to represent the number on the other side.  Note: we have to do this
@@ -1046,7 +1046,7 @@ async function getOrCreateEntryAsync(
     // Serializes out only the subset of properties of this object that we have seen used
     // and have recorded in localCapturedPropertyChains
     async function serializeSomeObjectPropertiesAsync(
-            object: ObjectInfo, localCapturedPropertyChains: CapturedPropertyChain[]): Promise<boolean> {
+        object: ObjectInfo, localCapturedPropertyChains: CapturedPropertyChain[]): Promise<boolean> {
 
         // validate our invariants.
         for (const chain of localCapturedPropertyChains) {
@@ -1422,8 +1422,8 @@ async function getOwnPropertyDescriptors(obj: any): Promise<ClosurePropertyDescr
 
 async function getOwnPropertyAsync(obj: any, descriptor: ClosurePropertyDescriptor): Promise<any> {
     return (descriptor.get || descriptor.set) ?
-      undefined :
-      obj[getNameOrSymbol(descriptor)];
+        undefined :
+        obj[getNameOrSymbol(descriptor)];
 }
 
 async function getPropertyAsync(obj: any, name: string): Promise<any> {
